@@ -1,18 +1,18 @@
 #[macro_use]
 extern crate prettytable;
 
+use log::info;
 use std::collections::HashMap;
 use std::fs::File;
 use std::path::{Path, PathBuf};
-use log::info;
 
 use prettytable::{format, row, Table};
 use structopt::StructOpt;
 
-use modeling::{by_dir, ClassInfo, ParseOption};
 use modeling::file_filter::FileFilter;
 use modeling::segment::segment;
 use modeling::segment::stop_words::{STOP_WORDS, TECH_STOP_WORDS};
+use modeling::{by_dir, ClassInfo, ParseOption};
 
 #[derive(StructOpt, Debug, PartialEq, Clone)]
 #[structopt(name = "basic")]
@@ -31,7 +31,6 @@ struct ConceptOpts {
     grep: String,
 }
 
-
 impl ConceptOpts {
     pub fn to_parse_option(&self) -> ParseOption {
         ParseOption {
@@ -39,7 +38,8 @@ impl ConceptOpts {
             field_only: false,
             without_parent: false,
             without_impl_suffix: false,
-            inline_id_suffix: false
+            inline_id_suffix: false,
+            without_suffix_text: "".to_string()
         }
     }
 }
@@ -51,7 +51,11 @@ fn main() {
     info!("parse input {:?} with {:?}", &opts.input, &opts);
 
     let parse_option = opts.to_parse_option();
-    let filter = FileFilter::new(opts.packages.clone(), opts.suffixes.clone(), opts.grep.clone());
+    let filter = FileFilter::new(
+        opts.packages.clone(),
+        opts.suffixes.clone(),
+        opts.grep.clone(),
+    );
 
     output_by_dir(&parse_option, &filter, &PathBuf::from(&opts.input));
 }
@@ -123,4 +127,4 @@ fn count_words(map: &mut HashMap<String, u32>, var: &str) {
         let counter = map.entry(word).or_insert(0);
         *counter += 1;
     }
-}
\ No newline at end of file
+}
