@@ -1,13 +1,13 @@
 use std::fs;
 
-use ignore::{WalkBuilder, DirEntry};
+use ignore::{DirEntry, WalkBuilder};
 use structopt::StructOpt;
 
-use modeling::{by_dir, ClassInfo, ParseOption};
 use modeling::file_filter::FileFilter;
-use modeling::render::{MermaidRender, PlantUmlRender};
-use std::ffi::OsStr;
 use modeling::render::graphviz_render::GraphvizRender;
+use modeling::render::{MermaidRender, PlantUmlRender};
+use modeling::{by_dir, ClassInfo, ParseOption};
+use std::ffi::OsStr;
 
 #[derive(StructOpt, Debug, PartialEq, Clone)]
 #[structopt(name = "Modeling")]
@@ -48,6 +48,9 @@ struct Opts {
     /// if class's prop end with Id and class in list, will replace `int` type to `xxClass`
     #[structopt(long)]
     inline_id_suffix: bool,
+    // remove some specify suffix for Field and Class name by text, for example `DemoDto` with be `Demo`
+    #[structopt(long, default_value = "")]
+    without_suffix_text: String
 }
 
 impl Opts {
@@ -58,6 +61,7 @@ impl Opts {
             without_parent: self.without_parent,
             without_impl_suffix: self.without_impl_suffix,
             inline_id_suffix: self.inline_id_suffix,
+            without_suffix_text: self.without_suffix_text.clone(),
         }
     }
 }
@@ -66,7 +70,11 @@ fn main() {
     let opts: Opts = Opts::from_args();
 
     let parse_option = opts.to_parse_option();
-    let filter = FileFilter::new(opts.packages.clone(), opts.suffixes.clone(), opts.grep.clone());
+    let filter = FileFilter::new(
+        opts.packages.clone(),
+        opts.suffixes.clone(),
+        opts.grep.clone(),
+    );
 
     if !opts.by_modules {
         output_all_in_one(opts, &parse_option, filter);
@@ -85,7 +93,13 @@ fn main() {
     }
 }
 
-fn output_by_dir(opts: &Opts, parse_option: &ParseOption, filter: &FileFilter, dir: &DirEntry, x: &OsStr) {
+fn output_by_dir(
+    opts: &Opts,
+    parse_option: &ParseOption,
+    filter: &FileFilter,
+    dir: &DirEntry,
+    x: &OsStr,
+) {
     let dir_name = x.to_str().unwrap();
     let classes = by_dir(dir.path(), filter.clone(), parse_option);
     if classes.len() > 0 {
