@@ -13,28 +13,20 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 use crate::coco_struct::{ClassInfo, MemberInfo, MethodInfo};
+use crate::ParseOption;
 use regex::Regex;
 use std::collections::HashMap;
 use std::fs::File;
 use std::io::{BufRead, BufReader};
 use std::path::PathBuf;
 use std::str::Lines;
-use crate::ParseOption;
 
+#[derive(Default)]
 pub struct CtagsParser {
     pub(crate) option: ParseOption,
     class_map: HashMap<String, ClassInfo>,
 }
 
-impl Default for CtagsParser {
-    fn default() -> Self {
-        CtagsParser {
-            option: Default::default(),
-            class_map: Default::default(),
-        }
-    }
-}
-
 lazy_static! {
     static ref CLASS_RE: Regex = Regex::new(
         r"(?x)
@@ -60,28 +52,26 @@ lazy_static! {
     .unwrap();
     static ref RE_ACCESS: Regex = Regex::new(r"access:(?P<access>[A-Za-z0-9_]+)").unwrap();
     static ref RE_LANGUAGE: Regex = Regex::new(r"language:(?P<language>[A-Za-z0-9_\#]+)").unwrap();
-
     static ref RE_TYPE: Regex =
         Regex::new(r"/\^([ ]*)(?P<datatype>[A-Za-z0-9_.]+)([^A-Za-z0-9_]+)(.*)\$/").unwrap();
     static ref RUST_TYPE: Regex = Regex::new(
         r"/\^([ ]*)(?P<field>[A-Za-z0-9_.\s]+)\s*:(\t|\s)*(?P<datatype>[A-Za-z0-9_.<>]+)"
-    ).unwrap();
-    static ref PURE_RUST_TYPE: Regex = Regex::new(
-        r"((Vec|Option|<)*)(?P<datatype>[A-Za-z0-9_]+)>*"
-    ).unwrap();
-
-    static ref GO_TYPE: Regex =
-        Regex::new(r"(?x)/\^([\s]*)
+    )
+    .unwrap();
+    static ref PURE_RUST_TYPE: Regex =
+        Regex::new(r"((Vec|Option|<)*)(?P<datatype>[A-Za-z0-9_]+)>*").unwrap();
+    static ref GO_TYPE: Regex = Regex::new(
+        r"(?x)/\^([\s]*)
 ([A-Za-z0-9_.]+)
 (,(\s|\t)*([A-Za-z0-9_.]+))*(\s|\t)* # for `name, access, returntype string`
-(?P<datatype>[A-Za-z0-9_.<>\[\]]+)").unwrap();
-    static ref TYPE_SCRIPT_TYPE: Regex = Regex::new(
-        r"/\^([ |\t]*).*:([ |\t]*)(?P<datatype>[A-Za-z0-9_.<>\[\]]+).*\$/"
-    ).unwrap();
-
+(?P<datatype>[A-Za-z0-9_.<>\[\]]+)"
+    )
+    .unwrap();
+    static ref TYPE_SCRIPT_TYPE: Regex =
+        Regex::new(r"/\^([ |\t]*).*:([ |\t]*)(?P<datatype>[A-Za-z0-9_.<>\[\]]+).*\$/").unwrap();
     static ref PARAMETER: Regex = Regex::new(r"/.*\((?P<parameters>(.*?))\).*/").unwrap();
-    static ref RUST_RETURN_TYPE: Regex = Regex::new(r"\s->\s(?P<datatype>[A-Za-z0-9_.]+)\s").unwrap();
-
+    static ref RUST_RETURN_TYPE: Regex =
+        Regex::new(r"\s->\s(?P<datatype>[A-Za-z0-9_.]+)\s").unwrap();
     static ref TYPE_KEYWORDS: [&'static str; 18] = [
         "private",
         "public",
@@ -127,18 +117,14 @@ impl CtagsParser {
         let reader = BufReader::new(file);
 
         let mut parser = CtagsParser::default();
-        for result in reader.lines() {
-            if let Ok(line) = result {
-                parser.parse_class(line.as_str());
-            };
+        for line in reader.lines().flatten() {
+            parser.parse_class(line.as_str());
         }
 
         let file = File::open(format!("{}", dir.display()).as_str()).expect("cannot find file");
         let reader = BufReader::new(file);
-        for result in reader.lines() {
-            if let Ok(line) = result {
-                parser.parse_method_methods(line.as_str());
-            };
+        for line in reader.lines().flatten() {
+            parser.parse_method_methods(line.as_str());
         }
 
         parser
@@ -154,7 +140,7 @@ impl CtagsParser {
             if let Some(inherits_capts) = INHERITS_RE.captures(line) {
                 let inherits_str = &inherits_capts["inherits"];
                 let inherits = inherits_str
-                    .split(",")
+                    .split(',')
                     .map(|s| s.to_string())
                     .collect::<Vec<String>>();
 
@@ -255,7 +241,8 @@ impl CtagsParser {
     }
 
     fn parse_rust_access(field_with_access: String) -> String {
-        let split = field_with_access.split(" ")
+        let split = field_with_access
+            .split(' ')
             .map(|s| s.to_string())
             .collect::<Vec<String>>();
 
@@ -264,7 +251,7 @@ impl CtagsParser {
                 "+".to_string()
             } else {
                 "#".to_string()
-            }
+            };
         }
 
         "-".to_string()
@@ -275,7 +262,7 @@ impl CtagsParser {
             line = line.replacen(keyword, "", 1)
         }
 
-        return line;
+        line
     }
 
     fn lookup_class_from_map(&mut self, line: &str) -> Option<&mut ClassInfo> {
@@ -286,12 +273,12 @@ impl CtagsParser {
         }
 
         let package = class_name.clone();
-        let split = class_name.split(".");
+        let split = class_name.split('.');
         if let Some(last) = split.last() {
             class_name = last.to_string();
         }
 
-        if class_name.len() <= 0 {
+        if class_name.is_empty() {
             return None;
         }
 
@@ -320,10 +307,13 @@ impl CtagsParser {
                 .members
                 .sort_by(|a, b| a.name.to_lowercase().cmp(&b.name.to_lowercase()));
 
-
             if self.option.merge {
-                clazz.methods.dedup_by(|a, b| a.name.eq_ignore_ascii_case(&*b.name));
-                clazz.members.dedup_by(|a, b| a.name.eq_ignore_ascii_case(&*b.name));
+                clazz
+                    .methods
+                    .dedup_by(|a, b| a.name.eq_ignore_ascii_case(&*b.name));
+                clazz
+                    .members
+                    .dedup_by(|a, b| a.name.eq_ignore_ascii_case(&*b.name));
             }
 
             classes.push(clazz);
@@ -335,17 +325,18 @@ impl CtagsParser {
     }
 
     fn pick_parameter_list(signature: &str) -> Vec<String> {
-        PARAMETER.captures(signature).and_then(
-            |cap| cap.name("parameters")
-                .map(|s| s.as_str())
-                .and_then(|s| {
+        PARAMETER
+            .captures(signature)
+            .and_then(|cap| {
+                cap.name("parameters").map(|s| s.as_str()).and_then(|s| {
                     if s.is_empty() {
                         None
                     } else {
                         Some(s.split(',').map(|s| s.to_string()).collect())
                     }
                 })
-        ).unwrap_or(vec![])
+            })
+            .unwrap_or_default()
     }
 }
 
@@ -355,10 +346,9 @@ mod test {
     use std::path::PathBuf;
 
     pub fn tags_dir() -> PathBuf {
-        let root_dir = PathBuf::from(env!("CARGO_MANIFEST_DIR"));
-        let ctags_dir = root_dir.join("_fixtures").join("ctags");
-
-        return ctags_dir;
+        PathBuf::from(env!("CARGO_MANIFEST_DIR"))
+            .join("_fixtures")
+            .join("ctags")
     }
 
     #[test]
@@ -371,8 +361,7 @@ mod test {
         let str = "MethodIdentifier	SubscriberRegistry.java	/^    MethodIdentifier(Method method) {$/;\"	method	line:239	language:Java	class:SubscriberRegistry.MethodIdentifier	access:default
 MethodIdentifier	SubscriberRegistry.java	/^  private static final class MethodIdentifier {$/;\"	class	line:234	language:Java	class:SubscriberRegistry	access:private";
 
-        let mut lines = vec![];
-        lines.push(str.lines());
+        let lines = vec![str.lines()];
         let parser = CtagsParser::parse_str(lines);
         let classes = parser.classes();
 
@@ -396,8 +385,7 @@ MethodIdentifier	SubscriberRegistry.java	/^  private static final class MethodId
             "MethodInfo	src/coco_struct.rs	/^pub struct MethodInfo {$/;\"	struct	line:21	language:Rust
 name	src/coco_struct.rs	/^    pub name: String,$/;\"	field	line:22	language:Rust	struct:MethodInfo";
 
-        let mut lines = vec![];
-        lines.push(str.lines());
+        let lines = vec![str.lines()];
         let parser = CtagsParser::parse_str(lines);
         let classes = parser.classes();
 
@@ -408,12 +396,10 @@ name	src/coco_struct.rs	/^    pub name: String,$/;\"	field	line:22	language:Rust
 
     #[test]
     pub fn should_build_rust_method_datatype() {
-        let str =
-            r#"GraphvizRender	graphviz_render.rs	/^pub struct GraphvizRender;$/;"	struct	line:11	language:Rust
+        let str = r#"GraphvizRender	graphviz_render.rs	/^pub struct GraphvizRender;$/;"	struct	line:11	language:Rust
 render	graphviz_render.rs	/^    pub fn render(classes: &Vec<ClassInfo>, parse_option: &ParseOption) -> String {$/;"	method	line:35	language:Rust	implementation:GraphvizRender"#;
 
-        let mut lines = vec![];
-        lines.push(str.lines());
+        let lines = vec![str.lines()];
         let parser = CtagsParser::parse_str(lines);
         let classes = parser.classes();
 
@@ -533,8 +519,7 @@ MethodIdentifier	SubscriberRegistry.java	/^    MethodIdentifier(Method method) {
 MethodIdentifier	SubscriberRegistry.java	/^    MethodIdentifier(Method method) {$/;\"	method	line:238	language:Java	class:SubscriberRegistry.MethodIdentifier	access:default
 MethodIdentifier	SubscriberRegistry.java	/^  private static final class MethodIdentifier {$/;\"	class	line:234	language:Java	class:SubscriberRegistry	access:private";
 
-        let mut lines = vec![];
-        lines.push(str.lines());
+        let lines = vec![str.lines()];
         let parser = CtagsParser::parse_str(lines.clone());
         let classes = parser.classes();
 
