@@ -2,8 +2,9 @@
 extern crate lazy_static;
 extern crate serde;
 
-use ignore::Walk;
+use std::path::Path;
 
+use ignore::Walk;
 use structopt::StructOpt;
 
 pub use coco_struct::{ClassInfo, MemberInfo, MethodInfo};
@@ -13,14 +14,13 @@ pub use ctags::ctags_parser::CtagsParser;
 pub use file_filter::*;
 pub use parse_option::ParseOption;
 
-use std::path::Path;
 use crate::file_filter::FileFilter;
 
-pub mod ctags;
-pub mod render;
 pub mod coco_struct;
+pub mod ctags;
 pub mod file_filter;
 pub mod parse_option;
+pub mod render;
 pub mod segment;
 
 /// Returns Vec<ClassInfo> with the given path.
@@ -40,7 +40,7 @@ pub mod segment;
 /// let puml = PlantUmlRender::render(&classes, &ParseOption::default());
 /// ```
 pub fn by_dir<P: AsRef<Path>>(path: P, filter: FileFilter, option: &ParseOption) -> Vec<ClassInfo> {
-    by_files(files_from_path(path, filter), &option)
+    by_files(files_from_path(path, filter), option)
 }
 
 /// Returns Vec<ClassInfo> with the given files.
@@ -64,10 +64,10 @@ pub fn by_files(files: Vec<String>, option: &ParseOption) -> Vec<ClassInfo> {
     let thread = count_thread(&files);
     let opt = build_opt(thread);
 
-    run_ctags(&opt, &files_by_thread(files, &opt), &option)
+    run_ctags(&opt, &files_by_thread(files, &opt), option)
 }
 
-fn count_thread(origin_files: &Vec<String>) -> usize {
+fn count_thread(origin_files: &[String]) -> usize {
     let mut thread = origin_files.len();
     let default_ptags_thread = 8;
     if thread >= default_ptags_thread {
@@ -76,8 +76,8 @@ fn count_thread(origin_files: &Vec<String>) -> usize {
     thread
 }
 
-fn run_ctags(opt: &Opt, files: &Vec<String>, option: &ParseOption) -> Vec<ClassInfo> {
-    let outputs = CmdCtags::call(&opt, &files).unwrap();
+fn run_ctags(opt: &Opt, files: &[String], option: &ParseOption) -> Vec<ClassInfo> {
+    let outputs = CmdCtags::call(opt, files).unwrap();
     let mut iters = Vec::new();
     for o in &outputs {
         let iter = if opt.validate_utf8 {
@@ -89,21 +89,18 @@ fn run_ctags(opt: &Opt, files: &Vec<String>, option: &ParseOption) -> Vec<ClassI
     }
 
     let mut parser = CtagsParser::parse_str(iters);
-    parser.option = option.clone();
-    let classes = parser.classes();
 
-    classes
+    parser.option = option.clone();
+    parser.classes()
 }
 
 fn files_from_path<P: AsRef<Path>>(path: P, filter: FileFilter) -> Vec<String> {
     let mut origin_files = vec![];
-    for result in Walk::new(path) {
-        if let Ok(entry) = result {
-            if entry.file_type().unwrap().is_file() {
-                let buf = entry.path().to_path_buf();
-                if filter.allow(buf) {
-                    origin_files.push(format!("{}", entry.path().display()))
-                }
+    for entry in Walk::new(path).flatten() {
+        if entry.file_type().unwrap().is_file() {
+            let buf = entry.path().to_path_buf();
+            if filter.allow(buf) {
+                origin_files.push(format!("{}", entry.path().display()))
             }
         }
     }
@@ -115,7 +112,7 @@ fn files_by_thread(origin_files: Vec<String>, opt: &Opt) -> Vec<String> {
     let mut files = vec![String::from(""); opt.thread];
     for (i, f) in origin_files.iter().enumerate() {
         files[i % opt.thread].push_str(f);
-        files[i % opt.thread].push_str("\n");
+        files[i % opt.thread].push('\n');
     }
     files
 }
@@ -130,20 +127,19 @@ fn build_opt(thread: usize) -> Opt {
 
 #[cfg(test)]
 mod tests {
-    use std::path::PathBuf;
     use std::fs;
+    use std::path::PathBuf;
+
+    use crate::file_filter::FileFilter;
     use crate::render::{MermaidRender, PlantUmlRender};
     use crate::{by_dir, ParseOption};
-    use crate::file_filter::FileFilter;
 
     pub fn ctags_fixtures_dir() -> PathBuf {
-        let root_dir = PathBuf::from(env!("CARGO_MANIFEST_DIR"));
-        let ctags_dir = root_dir.join("_fixtures")
+        PathBuf::from(env!("CARGO_MANIFEST_DIR"))
+            .join("_fixtures")
             .join("ctags")
             .join("source")
-            .join("animal.ts");
-
-        return ctags_dir;
+            .join("animal.ts")
     }
 
     #[test]
@@ -164,16 +160,18 @@ mod tests {
     #[test]
     fn should_only_have_one_file() {
         let root_dir = PathBuf::from(env!("CARGO_MANIFEST_DIR"));
-        let ctags_dir = root_dir.join("_fixtures")
-            .join("ctags")
-            .join("source");
+        let ctags_dir = root_dir.join("_fixtures").join("ctags").join("source");
 
         let path = format!("{}", ctags_dir.display());
 
         let suffixes = vec!["store".to_string()];
 
         let option = ParseOption::default();
-        let vec = by_dir(path, FileFilter::new(vec![], suffixes, "".to_string()), &option);
+        let vec = by_dir(
+            path,
+            FileFilter::new(vec![], suffixes, "".to_string()),
+            &option,
+        );
 
         assert_eq!(3, vec.len());
         let result = PlantUmlRender::render(&vec, &option);
@@ -191,7 +189,11 @@ mod tests {
         let path = format!("{}", ctags_dir.display());
 
         let option = ParseOption::default();
-        let vec = by_dir(path, FileFilter::new(vec![], vec![], "".to_string()), &option);
+        let vec = by_dir(
+            path,
+            FileFilter::new(vec![], vec![], "".to_string()),
+            &option,
+        );
 
         assert_eq!(3, vec.len());
     }
@@ -199,9 +201,7 @@ mod tests {
     #[test]
     fn should_filter_by_grep() {
         let root_dir = PathBuf::from(env!("CARGO_MANIFEST_DIR"));
-        let ctags_dir = root_dir.join("_fixtures")
-            .join("ctags")
-            .join("source");
+        let ctags_dir = root_dir.join("_fixtures").join("ctags").join("source");
 
         let path = format!("{}", ctags_dir.display());
 
@@ -221,11 +221,9 @@ mod tests {
         assert_eq!(3, vec.len());
         let result = MermaidRender::render(&vec, &option);
 
-        println!("{:?}", result);
-
         let _ = fs::write("demo.puml", result.clone());
         assert!(result.contains("class Animal"));
         assert!(result.contains("Animal <|-- Horse"));
         assert!(result.contains("Animal <|-- Snake"));
     }
-}
\ No newline at end of file
+}
