@@ -4,8 +4,8 @@ use std::fs;
 use serde::{Deserialize, Serialize};
 
 use crate::coco_struct::ClassInfo;
+use crate::render::{process_name, render_member, render_method};
 use crate::ParseOption;
-use crate::render::{render_member, render_method};
 
 /// Render classes info to string
 pub struct GraphvizRender;
@@ -39,7 +39,7 @@ impl GraphvizRender {
 
         let mut class_map: HashMap<String, bool> = HashMap::default();
         for clazz in classes {
-            class_map.insert(clazz.name.clone(), true);
+            class_map.insert(process_name(&parse_option, &clazz.name), true);
         }
 
         let class_catalog = Self::catalog_mvc_to_index();
@@ -48,11 +48,18 @@ impl GraphvizRender {
         for clazz in classes {
             let mut dep_map: HashMap<String, String> = HashMap::default();
 
-            Self::create_data_nodes(&mut sub_graphs_map, &mut data, &class_catalog, &layer_cluster, &clazz);
+            Self::create_data_nodes(
+                &mut sub_graphs_map,
+                &mut data,
+                &class_catalog,
+                &layer_cluster,
+                &clazz,
+                &parse_option
+            );
 
             let _ = render_member(&clazz, &mut dep_map, "", parse_option, &mut class_map);
             if !parse_option.field_only {
-                let _ = render_method(&clazz, &mut dep_map, "");
+                let _ = render_method(&clazz, &mut dep_map, "", parse_option);
             }
 
             for (callee, current_clz) in dep_map {
@@ -71,13 +78,22 @@ impl GraphvizRender {
                     deps.push(format!("{} -> {}\n", current_clz, callee));
                 }
 
-                data.links.push(DLink { source: current_clz, target: callee, package: clazz.package.clone(), value: 1, })
+                data.links.push(DLink {
+                    source: current_clz,
+                    target: callee,
+                    package: clazz.package.clone(),
+                    value: 1,
+                })
             }
         }
 
         let mut sub_graphs = vec![];
         for (key, items) in sub_graphs_map {
-            sub_graphs.push(format!("\n  subgraph cluster_{}{{\n    {}\n    }}", key.to_lowercase(), items.join("\n    ")));
+            sub_graphs.push(format!(
+                "\n  subgraph cluster_{}{{\n    {}\n    }}",
+                key.to_lowercase(),
+                items.join("\n    ")
+            ));
         }
 
         let _ = fs::write("output.json", serde_json::to_string(&data).unwrap());
@@ -93,9 +109,16 @@ impl GraphvizRender {
         )
     }
 
-    fn create_data_nodes(sub_graphs_map: &mut HashMap<String, Vec<String>>, data: &mut DData, class_catalog: &HashMap<&str, usize>, layer_cluster: &HashMap<usize, &str>, clazz: &&ClassInfo) {
+    fn create_data_nodes(
+        sub_graphs_map: &mut HashMap<String, Vec<String>>,
+        data: &mut DData,
+        class_catalog: &HashMap<&str, usize>,
+        layer_cluster: &HashMap<usize, &str>,
+        clazz: &ClassInfo,
+        parse_option: &ParseOption,
+    ) {
         let mut has_catalog = false;
-        let class_name = &clazz.name;
+        let class_name = process_name(&parse_option, &clazz.name);
         for (key, value) in class_catalog {
             if class_name.ends_with(key) {
                 has_catalog = true;
@@ -139,11 +162,10 @@ impl GraphvizRender {
     }
 }
 
-
 #[cfg(test)]
 mod tests {
-    use crate::{ClassInfo, ParseOption};
     use crate::render::graphviz_render::GraphvizRender;
+    use crate::{ClassInfo, ParseOption};
 
     #[test]
     fn should_render_graphviz() {
@@ -152,4 +174,4 @@ mod tests {
         let string = GraphvizRender::render(&clzs, &ParseOption::default());
         assert_eq!("digraph G {\n  compound=true;\n  ranksep=1\n  node[shape=record]\n\n  subgraph cluster_service{\n    WorldServiceImpl\n    }\n\n}", string);
     }
-}
\ No newline at end of file
+}
