@@ -1,8 +1,8 @@
 use std::collections::HashMap;
 
 use crate::coco_struct::ClassInfo;
+use crate::render::{process_name, render_member, render_method};
 use crate::ParseOption;
-use crate::render::{render_member, render_method};
 
 /// Render classes info to string
 pub struct PlantUmlRender;
@@ -14,27 +14,27 @@ impl PlantUmlRender {
 
         let mut class_map: HashMap<String, bool> = HashMap::default();
         for clazz in classes {
-            class_map.insert(clazz.name.clone(), true);
+            class_map.insert(process_name(&parse_option, &clazz.name), true);
         }
 
         for clazz in classes {
             let mut dep_map: HashMap<String, String> = HashMap::default();
 
             let members = render_member(&clazz, &mut dep_map, "", parse_option, &mut class_map);
-            let mut methods= vec![];
+            let mut methods = vec![];
             if !parse_option.field_only {
-                methods = render_method(&clazz, &mut dep_map, "");
+                methods = render_method(&clazz, &mut dep_map, "", parse_option);
             }
 
             let content = format!("{}{}", members.join(""), methods.join(""));
-            let class_field = clazz.name.clone();
+            let clazz_name = process_name(&parse_option, &clazz.name);
             if clazz.parents.len() > 0 && !parse_option.without_parent {
                 for parent in &clazz.parents {
                     rendered.push(format!("{} <|-- {}", parent, clazz.name));
                 }
             }
 
-            rendered.push(format!("class {} {{\n{}}}", class_field, content));
+            rendered.push(format!("class {} {{\n{}}}", clazz_name, content));
 
             for (callee, current_clz) in dep_map {
                 if callee == current_clz {
